@@ -1,4 +1,6 @@
 from typing import Any, Dict
+import os
+import sys
 
 from fastapi import Request
 import requests
@@ -37,6 +39,22 @@ async def process_webhook(request: Request) -> Dict[str, Any]:
         return process_failed_msg
 
     logger = get_logger_with_params(name=logger_name, repository_name=hook_data["repository"]["name"])
-    api: ProcessGithubWehook = ProcessGithubWehook(hook_data=hook_data, headers=request.headers, logger=logger)
-    api.process()
-    return {"status": requests.codes.ok, "message": "process success", "log_prefix": delivery_headers}
+    try:
+        api: ProcessGithubWehook = ProcessGithubWehook(hook_data=hook_data, headers=request.headers, logger=logger)
+        api.process()
+        return {"status": requests.codes.ok, "message": "process success", "log_prefix": delivery_headers}
+
+    except Exception as exp:
+        logger.error(f"Error: {exp}")
+        exc_type, exc_obj, exc_tb = sys.exc_info()  # noqa: F841
+        msg = f"Error: {exc_type}"
+
+        if exc_tb is not None:
+            file_name = os.path.split(exc_tb.tb_frame.f_code.co_filename)
+            msg = f"Error: {exc_type}, File: {file_name}, Line: {exc_tb.tb_lineno}"
+
+        return {
+            "status": requests.codes.server_error,
+            "message": msg,
+            "log_prefix": delivery_headers,
+        }
